@@ -34,9 +34,9 @@ pub fn new(url: String, secret: String) -> TxlogClient {
 }
 
 pub struct SubmitMetadata {
-    metadata: Option<String>,
-    merchant: Option<String>,
-    network: Option<String>,
+    pub metadata: Option<String>,
+    pub merchant: Option<String>,
+    pub network: Option<String>,
 }
 
 impl TxlogClient {
